==> json-joy-5.0.0.tgz: package/esm/reactive-rpc/common/json-rpc/JsonRpc2Server.js <==
const isArray = Array.isArray;
export class JsonRpc2Server {
    constructor(params) {
        this.caller = params.caller;
        this.strict = !!params.strict;
        this.onNotification = params.onNotification;
        this.codec = params.codec;
    }
    async onMessage(ctx, message) {
        let id = null;
        try {
            if (!message || typeof message !== 'object' || isArray(message))
                return this.codec.encodeInvalidRequestError(id);
            const isNotification = typeof message.id !== 'number' && typeof message.id !== 'string';
            if (!isNotification)
                id = message.id;
            if (message.method === undefined)
                return this.codec.encodeMethodNotFoundError(id);
            const method = message.method;
            if (typeof method !== 'string')
                return this.codec.encodeMethodNotFoundError(id);
            if (this.strict && message.jsonrpc !== '2.0')
                return this.codec.encodeInvalidRequestError(id);
            if (isNotification)
                return this.onNotification(method, message.params, ctx);
            if (!this.caller.exists(method))
                return this.codec.encodeMethodNotFoundError(id);
            const result = await this.caller.call(method, message.params, ctx);
            if (result === undefined)
                return undefined;
            return this.codec.encodeResponse(id, result);
        }
        catch (error) {
            const rpcError = {
                code: !!error && typeof error === 'object' && typeof error.code === 'number' ? error.code : 0,
                message: error instanceof Error
                    ? error.message
                    : !!error && typeof error === 'object'
                        ? String(error.message)
                        : String(error),
            };
            if (!!error && typeof error === 'object' && error.data !== undefined)
                rpcError.data = error.data;
            return this.codec.encodeError(rpcError, id);
        }
    }
    async onMessages(ctx, data) {
        try {
            const messages = this.codec.decode(data);
            const results = await Promise.all(messages.map(async (message) => this.onMessage(ctx, message)));
            const resultsFiltered = results.filter(res => res !== undefined);
            if (resultsFiltered.length < 2)
                return resultsFiltered[0];
            return this.codec.encodeBatch(resultsFiltered);
        }
        catch (error) {
            return this.codec.encodeParseError();
        }
    }
}

==> json-joy-5.2.0.tgz: package/esm/reactive-rpc/common/json-rpc/JsonRpc2Server.js <==
const isArray = Array.isArray;
export class JsonRpc2Server {
    constructor(params) {
        this.caller = params.caller;
        this.strict = !!params.strict;
        this.onNotification = params.onNotification;
        this.codec = params.codec;
    }
    async onMessage(ctx, message) {
        let id = null;
        try {
            if (!message || typeof message !== 'object' || isArray(message))
                return this.codec.encodeInvalidRequestError(id);
            const isNotification = typeof message.id !== 'number' &&
                typeof message.id !== 'string';
            if (!isNotification)
                id = message.id;
            if (message.method === undefined)
                return this.codec.encodeMethodNotFoundError(id);
            const method = message.method;
            if (typeof method !== 'string')
                return this.codec.encodeMethodNotFoundError(id);
            if (this.strict && message.jsonrpc !== '2.0')
                return this.codec.encodeInvalidRequestError(id);
            if (isNotification)
                return this.onNotification(method, message.params, ctx);
            if (!this.caller.exists(method))
                return this.codec.encodeMethodNotFoundError(id);
            const result = await this.caller.call(method, message.params, ctx);
            if (result === undefined)
                return undefined;
            return this.codec.encodeResponse(id, result);
        }
        catch (error) {
            const rpcError = {
                code: !!error && typeof error === 'object' && typeof error.code === 'number' ? error.code : 0,
                message: error instanceof Error
                    ? error.message
                    : !!error && typeof error === 'object'
                        ? String(error.message)
                        : String(error),
            };
            if (!!error && typeof error === 'object' && error.data !== undefined)
                rpcError.data = error.data;
            return this.codec.encodeError(rpcError, id);
        }
    }
    async onMessages(ctx, data) {
        try {
            const messages = this.codec.decode(data);
            const results = await Promise.all(messages.map(async (message) => this.onMessage(ctx, message)));
            const resultsFiltered = results.filter((res) => res !== undefined);
            if (resultsFiltered.length < 2)
                return resultsFiltered[0];
            return this.codec.encodeBatch(resultsFiltered);
        }
        catch (error) {
            return this.codec.encodeParseError();
        }
    }
}
